# Copyright (c) 2000-2010, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%define with()          %{expand:%%{?with_%{1}:1}%%{!?with_%{1}:0}}
%define without()       %{expand:%%{?with_%{1}:0}%%{!?with_%{1}:1}}
%define bcond_with()    %{expand:%%{?_with_%{1}:%%global with_%{1} 1}}
%define bcond_without() %{expand:%%{!?_without_%{1}:%%global with_%{1} 1}}

%bcond_with gcj_support

%if %with gcj_support
%define gcj_support 1
%else
%define gcj_support 0
%endif

%define section free

Name:           crimson
Version:        1.1.3
Release:	20%{?dist}
Epoch:          0
Summary:        Java XML parser
Group:          Text Processing/Markup/XML
License:        ASL 1.1
URL:            http://xml.apache.org/crimson/
Source0:        http://xml.apache.org/dist/%{name}/%{name}-%{version}-src.tar.gz
Source1:        http://mirrors.ibiblio.org/pub/mirrors/maven2/crimson/crimson/1.1.3/crimson-1.1.3.pom
Source2:        xml-commons-1.0.b2.tar.bz2
Provides:       jaxp_parser_impl
Requires:       xml-commons-jaxp-1.1-apis
Requires(post): jpackage-utils
Requires(postun): jpackage-utils
Requires(post): %{_sbindir}/update-alternatives
Requires(preun): %{_sbindir}/update-alternatives
Requires:       jpackage-utils
BuildRequires:  ant
BuildRequires:  jpackage-utils
BuildRequires:  xml-commons-jaxp-1.1-apis
%if %{gcj_support}
BuildRequires: java-gcj-compat-devel
%else
BuildArch: noarch
%endif
BuildRoot:     %{_tmppath}/%{name}-%{version}-%{release}-root

%description
Crimson is a Java XML parser which supports XML 1.0 via the following
APIs:
- Java API for XML Processing (JAXP) 1.1 minus the javax.xml.transform
package. JAXP is a pluggable API that allows applications to access XML
documents in a parser-independent manner. It endorses the industry
standard SAX and DOM APIs and also adds a few classes under the
javax.xml.parsers package to implement pluggability and utility methods
Note: the javax.xml.transform package hierarchy of JAXP is not
implemented by Crimson. One implementation of javax.xml.transform can be
found at Xalan Java 2.
- SAX 2.0
- SAX2 Extensions version 1.0
- DOM Level 2 Core Recommendation

%package manual
Summary:        Manual for %{name}
Group:          Text Processing/Markup/XML

%description manual
Documentation for %{name}.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Documentation

%description javadoc
Javadoc for %{name}.

%package demo
Summary:        Demo for %{name}
Group:          Text Processing/Markup/XML
Requires:       %{name} = %{epoch}:%{version}-%{release}

%description demo
Demonstrations and samples for %{name}.

%prep
%setup -q
tar xjf %{SOURCE2}

# -----------------------------------------------------------------------------

%build
export OPT_JAR_LIST=:
export CLASSPATH=$(build-classpath xml-commons-jaxp-1.1-apis)
%{ant} -Dbuild.sysclasspath=first -Dxml-commons.name=xml-commons-1_0_b2 jar javadoc

# -----------------------------------------------------------------------------

%install
%{__rm} -rf %{buildroot}

# jars
%{__mkdir_p} %{buildroot}%{_javadir}
%{__cp} -p build/%{name}.jar %{buildroot}%{_javadir}/%{name}-%{version}.jar
(cd %{buildroot}%{_javadir} && for jar in *-%{version}*; do %{__ln_s} ${jar} `/bin/echo $jar | %{__sed} "s|-%{version}||g"`; done)

# javadoc
%{__mkdir_p} %{buildroot}%{_javadocdir}/%{name}-%{version}
%{__cp} -pr build/docs/api/* %{buildroot}%{_javadocdir}/%{name}-%{version}
%{__ln_s} %{name}-%{version} %{buildroot}%{_javadocdir}/%{name}

# demo
%{__mkdir_p} %{buildroot}%{_datadir}/%{name}
%{__cp} -pr examples %{buildroot}%{_datadir}/%{name}

# jaxp_parser_impl ghost symlink
%{__ln_s} %{_sysconfdir}/alternatives %{buildroot}%{_javadir}/jaxp_parser_impl.jar

# maven
%{__mkdir_p} %{buildroot}%{_datadir}/maven2/poms
%{__cp} -p %{SOURCE1} %{buildroot}%{_datadir}/maven2/poms/JPP-%{name}.pom
%add_to_maven_depmap crimson crimson %{version} JPP %{name}

%if %{gcj_support}
%{_bindir}/aot-compile-rpm
%endif

%clean
%{__rm} -rf %{buildroot}

# -----------------------------------------------------------------------------

%post
%{_sbindir}/update-alternatives --install %{_javadir}/jaxp_parser_impl.jar jaxp_parser_impl %{_javadir}/%{name}.jar 20
%if %{gcj_support}
if [ -x %{_bindir}/rebuild-gcj-db ]; then
    %{_bindir}/rebuild-gcj-db
fi
%endif
%update_maven_depmap

%preun
if [ "$1" -eq 0 ]; then
    %{_sbindir}/update-alternatives --remove jaxp_parser_impl %{_javadir}/%{name}.jar
fi

%postun
%update_maven_depmap
%if %{gcj_support}
if [ -x %{_bindir}/rebuild-gcj-db ]; then
    %{_bindir}/rebuild-gcj-db
fi
%endif

%files
%defattr(0644,root,root,0755)
%doc ChangeLog README.txt
%{_javadir}/%{name}-%{version}.jar
%{_javadir}/%{name}.jar
%ghost %{_javadir}/jaxp_parser_impl.jar
%{_datadir}/maven2/poms/JPP-%{name}.pom
%{_mavendepmapfragdir}/%{name}
%if %{gcj_support}
%dir %{_libdir}/gcj/%{name}
%attr(-,root,root) %{_libdir}/gcj/%{name}/%{name}-%{version}.jar.*
%endif

%files manual
%defattr(0644,root,root,0755)
%doc docs/*

%files javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/%{name}-%{version}
%{_javadocdir}/%{name}

%files demo
%defattr(0644,root,root,0755)
%{_datadir}/%{name}

%changelog
* Fri Sep 24 2010 Ralph Apel <r.apel@r-apel.de> 1.1.3-20
- Include API: it is supposed to be contained in crimson.jar

* Sat Jan 09 2010 Will Tatam <will.tatam@red61.com> 1.1.3-19
- Auto rebuild for JPackage 6 in centos5 mock

* Thu Jul 30 2009 David Walluck <dwalluck@redhat.com> 0:1.1.3-18
- build for JPP-6
- add maven support

* Wed May 30 2007 Jason Corley <jason.corley@gmail.com> - 0:1.1.3-17jpp
- syntactic cleanup
- rebuild in mock

* Fri May 11 2007 Ralph Apel <r.apel at r-apel.de> - 0:1.1.3-16jpp
- Make Vendor, Distribution based on macro

* Fri Feb 09 2007 Ralph Apel <r.apel at r-apel.de> - 0:1.1.3-15jpp
- Add gcj_support option
- Fix and reactivate javadoc

* Wed Jan 04 2006 Fernando Nasser <fnasser@redhat.com> - 0:1.1.3-14jpp
- First JPP 1.7 build

* Fri Aug 20 2004 Ralph Apel <r.apel at r-apel.de> - 0:1.1.3-13jpp
- Build with ant-1.6.2

* Wed Jun  4 2003 Ville Skyttä <ville.skytta at iki.fi> - 0:1.1.3-12jpp
- Own (ghost) %%{_javadir}/jaxp_parser_impl.jar.
- Remove alternatives in preun instead of postun.

* Thu Apr 10 2003 Ville Skyttä <ville.skytta at iki.fi> - 0:1.1.3-11jpp
- Rebuild for JPackage 1.5.
- Change alternative to point to non-versioned jar, don't remove it on upgrade.
- Don't include JAXP API classes in crimson.jar.
- Drop javadoc package (contained only JAXP APIs).

* Thu Aug 22 2002 Guillaume Rousse <guillomovitch@users.sourceforge.net> 1.1.3-10jpp
- corrected case for Group tag
- no macro for Url tag

* Mon Jul 01 2002 Guillaume Rousse <guillomovitch@users.sourceforge.net> 1.1.3-9jpp
- use sed instead of bash 2.x extension in link area to make spec compatible with distro using bash 1.1x
- provides jaxp_parser_impl
- priority lowered to 20

* Tue May 07 2002 Guillaume Rousse <guillomovitch@users.sourceforge.net> 1.1.3-8jpp
- vendor, distribution, group tags

* Sun Mar 10 2002 Guillaume Rousse <guillomovitch@users.sourceforge.net> 1.1.3-7jpp
- provides jaxp_parser2 virtual resource

* Sat Jan 19 2002 Guillaume Rousse <guillomovitch@users.sourceforge.net> 1.1.3-6jpp
- no need of stylebook, yet another cut'n'past sequel
- section macro

* Fri Jan 11 2002 Guillaume Rousse <guillomovitch@users.sourceforge.net> 1.1.3-5jpp
- fixed demo requires
- javadoc in %%{_datadir}/javadoc again

* Thu Dec 20 2001 Guillaume Rousse <guillomovitch@users.sourceforge.net> 1.1.3-4jpp
- javadoc back to /usr/share/doc
- doc and javadoc requires nothing
- demo requires exact version and release
- requires /usr/sbin/update-alternatives

* Wed Dec 5 2001 Guillaume Rousse <guillomovitch@users.sourceforge.net> 1.1.3-3jpp
- javadoc into javadoc package

* Wed Nov 21 2001 Christian Zoffoli <czoffoli@littlepenguin.org> 1.1.3-2jpp
- removed packager tag
- new jpp extension

* Sat Oct 6 2001 Guillaume Rousse <guillomovitch@users.sourceforge.net> 1.1.3-1jpp
- 1.1.3
- used original tarball

* Sun Sep 30 2001 Guillaume Rousse <guillomovitch@users.sourceforge.net> 1.1.2-0.beta2.2jpp
- first unified release
- s/jPackage/JPackage

* Fri Sep 07 2001 Guillaume Rousse <guillomovitch@users.sourceforge.net> 1.1.2-0.beta2.1mdk
- 1.1.2beta2
- used source distribution
- no more wrapper as one jar only
- example subpackage is now demo subpackage
- moved demo files in %%{_datadir}/%%{name}

* Sat Sep 01 2001 Guillaume Rousse <guillomovitch@users.sourceforge.net> 1.1.1-4mdk
- used cvs instead of mixed release
- moved examples %%{javadir}/%%{name}

* Tue Jul 31 2001 Guillaume Rousse <guillomovitch@users.sourceforge.net> 1.1.1-3mdk
- jaxp_parser symlink is now jaxp_parser.jar

* Tue Jul 24 2001 Guillaume Rousse <guillomovitch@users.sourceforge.net> 1.1.1-2mdk
- changed priority to 30

* Mon Jul 23 2001 Guillaume Rousse <guillomovitch@users.sourceforge.net> 1.1.1-1mdk
- first Mandrake release, using a build script stolen from Henry Gomez <gomez@slib.fr>
